shithub: qk1

Download patch

ref: fc395539c767849d9c3acc1b6e4d0979e054b708
parent: 0f96a8c069a9ea5459f9eb0372316bdb9aa4e526
author: Sigrid Solveig Haflínudóttir <sigrid@ftrv.se>
date: Sun Nov 26 19:31:27 EST 2023

aLways, aLready.

--- a/cl_input.c
+++ b/cl_input.c
@@ -336,7 +336,7 @@
 	if (cls.demoplayback)
 		return;
 
-	// allways dump the first two message, because it may contain leftover inputs
+	// always dump the first two message, because it may contain leftover inputs
 	// from the last level
 	if (++cl.movemessages <= 2)
 		return;
--- a/cmd.c
+++ b/cmd.c
@@ -258,7 +258,7 @@
 		return;
 	}
 
-	// if the alias allready exists, reuse it
+	// if the alias already exists, reuse it
 	for (a = cmd_alias ; a ; a=a->next)
 	{
 		if(strcmp(s, a->name) == 0)
--- a/cmd.h
+++ b/cmd.h
@@ -76,7 +76,7 @@
 char	*Cmd_Args (void);
 // The functions that execute commands get their parameters with these
 // functions. Cmd_Argv () will return an empty string, not a NULL
-// if arg > argc, so string operations are allways safe.
+// if arg > argc, so string operations are always safe.
 
 void	Cmd_ExecuteString (char *text, cmd_source_t src);
 // Parses a single line of text into arguments and tries to execute it.
--- a/cvar.h
+++ b/cvar.h
@@ -43,7 +43,7 @@
 } cvar_t;
 
 void 	Cvar_RegisterVariable (cvar_t *variable);
-// registers a cvar that allready has the name, string, and optionally the
+// registers a cvar that already has the name, string, and optionally the
 // archive elements set.
 
 float	Cvar_VariableValue (char *var_name);
--- a/host.c
+++ b/host.c
@@ -2,7 +2,7 @@
 
 /*
 
-A server can allways be started, even if the system started out as a client
+A server can always be started, even if the system started out as a client
 to a remote system.
 
 A client can NOT be started if the system started as a dedicated server.
--- a/menu.c
+++ b/menu.c
@@ -929,7 +929,7 @@
 		setcvarv ("volume", volume.value);
 		break;
 
-	case 8:	// allways run
+	case 8:	// always run
 		if (cl_forwardspeed.value > 200)
 		{
 			setcvarv ("cl_forwardspeed", 200);
--- a/pr_cmds.c
+++ b/pr_cmds.c
@@ -539,7 +539,7 @@
 weapon, feet, etc.
 
 Channel 0 is an auto-allocate channel, the others override anything
-allready running on that entity/channel pair.
+already running on that entity/channel pair.
 
 An attenuation of 0 will play full volume everywhere in the level.
 Larger attenuations will drop off.
--- a/render.h
+++ b/render.h
@@ -73,7 +73,7 @@
 	float		fvrectbottom;			// bottommost edge, for Alias clamping
 	float		horizontalFieldOfView;	// at Z = 1.0, this many X is visible
 										// 2.0 = 90 degrees
-	float		xOrigin;			// should probably allways be 0.5
+	float		xOrigin;			// should probably always be 0.5
 	float		yOrigin;			// between be around 0.3 to 0.5
 
 	vec3_t		vieworg;
--- a/sv_main.c
+++ b/sv_main.c
@@ -157,7 +157,7 @@
 weapon, feet, etc.
 
 Channel 0 is an auto-allocate channel, the others override anything
-allready running on that entity/channel pair.
+already running on that entity/channel pair.
 
 An attenuation of 0 will play full volume everywhere in the level.
 Larger attenuations will drop off.  (max 4 attenuation)
--- a/view.c
+++ b/view.c
@@ -682,7 +682,7 @@
 	VectorCopy (ent->angles, r_refdef.viewangles);
 	view->model = nil;
 
-	// allways idle in intermission
+	// always idle in intermission
 	old = v_idlescale.value;
 	v_idlescale.value = 1;
 	V_AddIdle ();
--- a/zone.c
+++ b/zone.c
@@ -176,7 +176,7 @@
 	mem_t *cs;
 
 	if(c->data)
-		fatal("Cache_Alloc: allready allocated");
+		fatal("Cache_Alloc: already allocated");
 	if(size <= 0)
 		fatal("Cache_Alloc: size %d", size);
--- a/cvar.c
+++ b/cvar.c
@@ -80,10 +80,10 @@
 {
 	char	*oldstr;
 
 	// first check to see if it has allready been defined
 	if (Cvar_FindVar (variable->name))
 	{
-		Con_Printf ("Can't register variable %s, allready defined\n", variable->name);
+		Con_Printf ("Can't register variable %s, already defined\n", variable->name);
 		return;
 	}
 
@@ -80,10 +80,10 @@
 	char	*oldstr;
 
-	// first check to see if it has allready been defined
+	// first check to see if it has already been defined
 	if (Cvar_FindVar (variable->name))
 	{
--- a/host_cmd.c
+++ b/host_cmd.c
@@ -591,7 +591,7 @@
 
 	if (sv_player->v.health <= 0)
 	{
-		SV_ClientPrintf ("Can't suicide -- allready dead!\n");
+		SV_ClientPrintf ("Can't suicide -- already dead!\n");
 		return;
 	}
 
@@ -678,13 +678,13 @@
 
 	if (host_client->spawned)
 	{
-		Con_Printf ("Spawn not valid -- allready spawned\n");
+		Con_Printf ("Spawn not valid -- already spawned\n");
 		return;
 	}
 
 	// run the entrance script
 	if (sv.loadgame)
-	{	// loaded games are fully inited allready
+	{	// loaded games are fully inited already
 		// if this is the last client to be connected, unpause
 		sv.paused = false;
 	}